@@ -1,7 +1,9 @@
 extern crate modern_terminal;
 
-use modern_terminal::base::console::Console;
-use modern_terminal::components::color_palette::ColorPalette;
+use modern_terminal::{
+    components::color_palette::ColorPalette,
+    core::console::Console,
+};
 
 fn main() -> std::io::Result<()> {
     let mut writer = std::io::stdout();
